@@ -1,12 +1,16 @@
-from collections import namedtuple
+from collections import namedtuple, OrderedDict
 from dcbase.lib.navLink import NavLink
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
-ProfileModel = namedtuple('ProfileModel', ['model', 'editUrl', 'name'])
+class ProfileModel(object):
+    def __init__(self, model):
+        self.model = model
+        self.editUrl = ''
+        self.name = ''
 
 class ProfileEditor(object):
-    _profileModels = []
+    _profileModels = OrderedDict()
 
     @classmethod
     def add_profile_edit_context(cls, context, navName, panelName):
@@ -24,11 +28,19 @@ class ProfileEditor(object):
         context['profilePanelHeading'] = panelName
 
     @classmethod
-    def register_profile_model(cls, model, profile_url, nav_name):
-        cls._profileModels.append(ProfileModel(model, profile_url, nav_name))
+    def register_profile_model(cls, model):
+        if model in cls._profileModels:
+            return
+        cls._profileModels[model] = ProfileModel(model)
+
+    @classmethod
+    def register_profile_view(cls, model, profile_url, nav_name):
+        cls.register_profile_model(model)
+        profileModel = cls._profileModels[model]
+        profileModel.editUrl = profile_url
+        profileModel.name = nav_name
 
     @classmethod
     def get_profile_models(cls):
-        return cls._profileModels
-
+        return cls._profileModels.values()
 
